==> sonnenbatterie-0.2.7-py3-none-any.whl: sonnenbatterie/const.py <==
from datetime import time
#from requests import Timeout


DEFAULT_BATTERY_LOGIN_TIMEOUT=120
DEFAULT_CONNECT_TO_BATTERY_TIMEOUT=60
DEFAULT_READ_FROM_BATTERY_TIMEOUT=60

SONNEN_OPERATING_MODE_UNKNOWN_NAME="Unknown Operating Mode"
SONNEN_OPERATING_MODE_UNKNOWN="0"
SONNEN_OPERATING_MODE_MANUAL_NAME="Manual"
SONNEN_OPERATING_MODE_AUTOMATIC_SELF_CONSUMPTION_NAME="Automatic - Self-Consumption"
SONNEN_OPERATING_MODE_BATTERY_MODULE_EXTENSION_30_PERCENT_NAME="Battery-Module-Extension (30%)"
SONNEN_OPERATING_MODE_TIME_OF_USE_NAME="Time-Of-Use"
SONNEN_OPERATING_MODE_NAMES_TO_OPERATING_MODES =  {SONNEN_OPERATING_MODE_MANUAL_NAME :"1", SONNEN_OPERATING_MODE_AUTOMATIC_SELF_CONSUMPTION_NAME:"2", SONNEN_OPERATING_MODE_BATTERY_MODULE_EXTENSION_30_PERCENT_NAME:"6", SONNEN_OPERATING_MODE_TIME_OF_USE_NAME:"10"}
SONNEN_OPERATING_MODES_TO_OPERATING_MODE_NAMES= {v:k for k,v in SONNEN_OPERATING_MODE_NAMES_TO_OPERATING_MODES.items()}

SONNEN_OPEATING_MODES=[SONNEN_OPERATING_MODE_MANUAL_NAME, SONNEN_OPERATING_MODE_AUTOMATIC_SELF_CONSUMPTION_NAME, SONNEN_OPERATING_MODE_BATTERY_MODULE_EXTENSION_30_PERCENT_NAME,SONNEN_OPERATING_MODE_TIME_OF_USE_NAME ]

SONNEN_CONFIGURATION_OPERATING_MODE="EM_OperatingMode"
SONNEN_CONFIGURATION_TOU_SCHEDULE="EM_ToU_Schedule"
SONNEN_CONFIGURATION_BACKUP_RESERVE="EM_USOC"
SONNEN_LATEST_DATA_CHARGE_LEVEL="USOC"

SONNEN_API_PATH_CONFIGURATIONS="v2/configurations"
SONNEN_API_PATH_LATEST_DATA="v2/latestdata"
SONNEN_API_PATH_POWER_METER="powermeter"
SONNEN_API_PATH_BATTERY_SYSTEM="battery_system"
SONNEN_API_PATH_INVERTER="inverter"
SONNEN_API_PATH_SYSTEM_DATA="system_data"
SONNEN_API_PATH_STATUS="v1/status"
SONNEN_API_PATH_BATTERY="battery"

SONNEN_CHARGE_PATH="charge"
SONNEN_DISCHARGE_PATH="discharge"

==> sonnenbatterie-0.4.0-py3-none-any.whl: sonnenbatterie/const.py <==
DEFAULT_BATTERY_LOGIN_TIMEOUT=120
DEFAULT_CONNECT_TO_BATTERY_TIMEOUT=60
DEFAULT_READ_FROM_BATTERY_TIMEOUT=60

SONNEN_OPERATING_MODE_UNKNOWN_NAME="Unknown Operating Mode"
SONNEN_OPERATING_MODE_UNKNOWN="0"
SONNEN_OPERATING_MODE_MANUAL_NAME="Manual"
SONNEN_OPERATING_MODE_AUTOMATIC_SELF_CONSUMPTION_NAME="Automatic - Self-Consumption"
SONNEN_OPERATING_MODE_BATTERY_MODULE_EXTENSION_30_PERCENT_NAME="Battery-Module-Extension (30%)"
SONNEN_OPERATING_MODE_TIME_OF_USE_NAME="Time-Of-Use"
SONNEN_OPERATING_MODE_NAMES_TO_OPERATING_MODES =  {
    SONNEN_OPERATING_MODE_MANUAL_NAME :"1",
    SONNEN_OPERATING_MODE_AUTOMATIC_SELF_CONSUMPTION_NAME:"2",
    SONNEN_OPERATING_MODE_BATTERY_MODULE_EXTENSION_30_PERCENT_NAME:"6",
    SONNEN_OPERATING_MODE_TIME_OF_USE_NAME:"10"
}
SONNEN_OPERATING_MODES_TO_OPERATING_MODE_NAMES = {v:k for k,v in SONNEN_OPERATING_MODE_NAMES_TO_OPERATING_MODES.items()}

SONNEN_OPEATING_MODES=[SONNEN_OPERATING_MODE_MANUAL_NAME, SONNEN_OPERATING_MODE_AUTOMATIC_SELF_CONSUMPTION_NAME, SONNEN_OPERATING_MODE_BATTERY_MODULE_EXTENSION_30_PERCENT_NAME,SONNEN_OPERATING_MODE_TIME_OF_USE_NAME ]

SONNEN_CONFIGURATION_OPERATING_MODE="EM_OperatingMode"
SONNEN_CONFIGURATION_TOU_SCHEDULE="EM_ToU_Schedule"
SONNEN_CONFIGURATION_BACKUP_RESERVE="EM_USOC"
SONNEN_LATEST_DATA_CHARGE_LEVEL="USOC"

SONNEN_API_PATH_CONFIGURATIONS="v2/configurations"
SONNEN_API_PATH_LATEST_DATA="v2/latestdata"
SONNEN_API_PATH_POWER_METER="powermeter"
SONNEN_API_PATH_BATTERY_SYSTEM="battery_system"
SONNEN_API_PATH_INVERTER="inverter"
SONNEN_API_PATH_SYSTEM_DATA="system_data"
SONNEN_API_PATH_STATUS="v1/status"
SONNEN_API_PATH_BATTERY="battery"

SONNEN_CHARGE_PATH="charge"
SONNEN_DISCHARGE_PATH="discharge"
